@@ -2,13 +2,16 @@
 
 import json
 from osgeo.ogr import Feature
-from typeguard import typechecked
+from vectorio.config import NoneType
+from typing import Union
 
 
 class FeatureGeojson(str):
 
-    @typechecked
-    def __new__(cls, feature: Feature):
+    def __new__(cls, feature: Union[Feature, NoneType]):
+        if feature is None:
+            return None
+
         content = json.dumps(
             json.loads(feature.ExportToJson()), ensure_ascii=False
         )
